debug

Macro debug 

macro_rules! debug {
    ( $format:expr $(, $arg:expr)* ) => { ... };
}
Format and write text to the WASM-4 debug console

Panics

The macro panics if the formatted string is larger than 100 bytes.

Undefined Behaviour

The behaviour is undefined is the formatted string is not valid UTF-8.

Examples

use wasm4fun_log::debug;

let h = 12;
let pi = 3.14;
debug!("There are {} hours in a day, and pi is {}", h, pi);